package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.VirtualPrivateCloudServices;

/**
 * 虚拟私有云服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface VirtualPrivateCloudServicesMapper 
{
    /**
     * 查询虚拟私有云服务
     * 
     * @param id 虚拟私有云服务主键
     * @return 虚拟私有云服务
     */
    public VirtualPrivateCloudServices selectVirtualPrivateCloudServicesById(Integer id);

    /**
     * 查询虚拟私有云服务列表
     * 
     * @param virtualPrivateCloudServices 虚拟私有云服务
     * @return 虚拟私有云服务集合
     */
    public List<VirtualPrivateCloudServices> selectVirtualPrivateCloudServicesList(VirtualPrivateCloudServices virtualPrivateCloudServices);

    /**
     * 新增虚拟私有云服务
     * 
     * @param virtualPrivateCloudServices 虚拟私有云服务
     * @return 结果
     */
    public int insertVirtualPrivateCloudServices(VirtualPrivateCloudServices virtualPrivateCloudServices);

    /**
     * 修改虚拟私有云服务
     * 
     * @param virtualPrivateCloudServices 虚拟私有云服务
     * @return 结果
     */
    public int updateVirtualPrivateCloudServices(VirtualPrivateCloudServices virtualPrivateCloudServices);

    /**
     * 删除虚拟私有云服务
     * 
     * @param id 虚拟私有云服务主键
     * @return 结果
     */
    public int deleteVirtualPrivateCloudServicesById(Integer id);

    /**
     * 批量删除虚拟私有云服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVirtualPrivateCloudServicesByIds(Integer[] ids);
}
